@@ -52,7 +52,7 @@ class Karel:
 
         Returns: None
         """
-        self.world = KarelWorld() if world_file is None else KarelWorld(world_file)
+        self.world = KarelWorld(world_file)
         self._avenue, self._street = self.world.karel_starting_location
         self._direction = self.world.karel_starting_direction
         self._num_beepers = self.world.karel_starting_beeper_count
@@ -359,7 +359,7 @@ class Karel:
 
         Parameters: None
         Returns:
-            beepers_on_corner (Bool) - True if there is at least one beeper on Karel's current corner
+            beepers_on_corner (Bool) - True if there's at least one beeper on Karel's current corner
                                        False otherwise
         """
         return self.world.beepers[(self.avenue, self.street)] != 0
@@ -460,7 +460,9 @@ class Karel:
                 self._avenue,
                 self._street,
                 self._direction,
-                f"Karel attempted to paint the corner with color {color}, which is not valid.",
+                "Karel attempted to paint the corner with color {}, which is not valid.".format(
+                    color
+                ),
             )
         self.world.paint_corner(self.avenue, self.street, color)
 
