@@ -19,11 +19,11 @@ class Tile:
         if self.value == "K" and self.beepers > 0:
             result += " <K> "
         elif self.beepers > 0:
-            result += f" <{self.beepers}> "
+            result += " <{}> ".format(self.beepers)
         elif self.color:
-            result += f" {self.color[:3]} "
+            result += " {} ".format(self.color[:3])
         else:
-            result += f"  {self.value}  "
+            result += "  {}  ".format(self.value)
         return result
 
 
@@ -46,7 +46,7 @@ def compare_output(first, second):
 
     def create_two_column_string(col1, col2):
         """ col1 and col2 are Lists. """
-        return map(lambda x: f"{x[0]}{' ' * SPACING}{x[1]}", zip(col1, col2))
+        return map(lambda x: "{}{}{}".format(x[0], " " * SPACING, x[1]), zip(col1, col2))
 
     def symmetric_difference(a, b):
         extra_a, extra_b = {}, {}
@@ -73,26 +73,32 @@ def compare_output(first, second):
     text_spacing = " " * (world_width - len(header1) + SPACING + 1)
     two_columns = create_two_column_string(this, that)
     output = "\n".join(two_columns)
-    fancy_arrows = f"{Color.RED.value}❯{Color.YELLOW.value}❯{Color.GREEN.value}❯ "
+    fancy_arrows = "{}❯{}❯{}❯ ".format(Color.RED.value, Color.YELLOW.value, Color.GREEN.value)
 
-    result = (
-        f"\n\n{fancy_arrows} {Color.YELLOW.value}{first.world.world_name}{Color.END.value}"
-        f"\n{header1}{text_spacing}{header2}\n{output}\n"
+    result = "\n\n{} {}{}{}" "\n{}{}{}\n{}\n".format(
+        fancy_arrows,
+        Color.YELLOW.value,
+        first.world.world_name,
+        Color.END.value,
+        header1,
+        text_spacing,
+        header2,
+        output,
     )
 
     if first.avenue != second.avenue or first.street != second.street:
         result += (
-            f"Karel did not end up in the same location in both worlds:\n"
-            f"Student: {(first.avenue, first.street)}\n"
-            f"Expected: {(second.avenue, second.street)}\n\n"
+            "Karel did not end up in the same location in both worlds:\n"
+            "Student: {}\n"
+            "Expected: {}\n\n".format((first.avenue, first.street), (second.avenue, second.street))
         )
     if first.world.beepers != second.world.beepers:
         extra_a, extra_b = symmetric_difference(first.world.beepers, second.world.beepers)
         result += (
-            f"Beepers do not match: "
-            f"(Only beepers that appear in one world but not the other are listed)\n"
-            f"Student: {extra_a}\n"
-            f"Expected: {extra_b}\n\n"
+            "Beepers do not match: "
+            "(Only beepers that appear in one world but not the other are listed)\n"
+            "Student: {}\n"
+            "Expected: {}\n\n".format(extra_a, extra_b)
         )
     return result
 
@@ -175,7 +181,7 @@ def karel_ascii(world, karel_street, karel_avenue):
             if world.corner_color(c, r):
                 world_arr[world.num_streets - r][c - 1].color = world.corner_color(c, r)
 
-    result = f"┌{HORIZONTAL * (CHAR_WIDTH * world.num_avenues + 1)}┐\n"
+    result = "┌{}┐\n".format(HORIZONTAL * (CHAR_WIDTH * world.num_avenues + 1))
     for r in range(world.num_streets):
         next_line = VERTICAL
         result += VERTICAL
@@ -187,9 +193,9 @@ def karel_ascii(world, karel_street, karel_avenue):
             result += VERTICAL if tile_pair_has_wall(r, c, Direction.WEST) else " "
             result += str(tile)
 
-        result += f" {VERTICAL}\n"
+        result += " {}\n".format(VERTICAL)
         if r == world.num_streets - 1:
-            result += f"└{HORIZONTAL * (CHAR_WIDTH * world.num_avenues + 1)}┘\n"
+            result += "└{}┘\n".format(HORIZONTAL * (CHAR_WIDTH * world.num_avenues + 1))
         else:
-            result += f"{next_line} {VERTICAL}\n"
+            result += "{} {}\n".format(next_line, VERTICAL)
     return result
